# -*- tab-width: 4 -*-
###########################################################################
#---------------------------------------------------------------------------+
# Licensed Materials - Property of IBM
# Rational ClearCase
# Copyright IBM Corp. 1998, 2005. All Rights Reserved
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract
# with IBM Corp.
#---------------------------------------------------------------------------+

use strict;
use Config;
use Fcntl;

BEGIN { 
	# configuration items - OS dependent
	if (!($CFG::UNIX || $CFG::NT)) {
		my $arch = $^O ? $^O : $main::Config{archname};
		$CFG::NT = (($arch =~ /^MSWin32/) || ($arch eq 'i386-win32')) ? 1 : 0;
	}
}

if ($CFG::NT) {
    $CFG::FS = qq/\\/;
    $CFG::UNIX = 0;
} else {
	if (!exists $ENV{CLEARCASEHOME}) {
        # check for (now deprecated) ATRIAHOME e.v.; use if set.
        if (exists $ENV{ATRIAHOME} ) {
			$ENV{CLEARCASEHOME} = $ENV{ATRIAHOME};
		} else {
            $ENV{CLEARCASEHOME} = "/opt/rational/clearcase";
        }
    }
    $CFG::FS = qq@\/@;
    $CFG::UNIX = 1;
}

# common tool definitions
# add "./" or ".\" to executable paths in case the user does not have "."
# on their PATH
my $dotslash = ".${CFG::FS}";
my $bindir = "${dotslash}bin" . $CFG::FS;
my $etcdir = "${dotslash}etc" . $CFG::FS;
$CFG::compress_pgm = "${etcdir}ccgzip";
$CFG::MultiTool = "${bindir}multitool";
$CFG::ClearTool = "${bindir}cleartool";

if ($CFG::NT) {
    $CFG::logdir = "$ENV{CLEARCASEHOME}${CFG::FS}var${CFG::FS}log";
    $CFG::shipping_server = "${bindir}shipping_server";
    $CFG::imsglog = "${bindir}imsglog";
    $CFG::workingdir_cmd = "cd";
    $CFG::nulldevice = "nul:";
    $CFG::script_configfile = "$ENV{CLEARCASEHOME}" .
        "${CFG::FS}var${CFG::FS}config${CFG::FS}MSimport_export.conf";
    $CFG::alternate_hostsfile = "";
} else {
    my $var_prod_dir = "/var/adm/rational/clearcase";
    $CFG::logdir = "${var_prod_dir}/log/sync_logs";
    $CFG::shipping_server = "${etcdir}shipping_server";
    $CFG::workingdir_cmd = "/bin/pwd";
    $CFG::nulldevice = "/dev/null";
    $CFG::script_configfile = "${var_prod_dir}/config/MSimport_export.conf";
    $CFG::ship_conf = "/var/adm/rational/clearcase/config/shipping.conf";
    $CFG::alternate_hostsfile = "${var_prod_dir}/config/alternate_hostnames";
}

# predeclare print functions
sub print2;
sub dbgprint;
sub qprint;

require 'ms_utils.pl';

# define this version - used by including scripts to check against mismatch
$CFG::MScommon_version = "7.0.0.0_syncmgr";

if (!$CFG::MS_script_version) {
    $CFG::MS_script_version = "(unknown older version)";
}

# give proper error message about parent script "requiring" syncmgr_common.pl
my $parent_script;
if ($CFG::including_script ne "") {
    $parent_script = $CFG::including_script;
} else {
    # parent script has not set its name; give unknown msg instead
    $parent_script = "('parent' script unknown)";
}

# define some parameter help that is common to various scripts

$CFG::workdir_parm_help = <<WDHELP;
    -workdir directory  Forces multitool to use this directory as its working
                        directory. Directory may exist, or will be created
                        if necessary. User must have necessary permissions to
                        access or create and write in the specified directory.

WDHELP

$CFG::trace_parm_help = <<THELP;
    -[no]trace          Display commands as they are executed, and
                        lists command-line options passed in. Forces the
                        log file to be kept.
                        (Default: "-notrace").
THELP

$CFG::help_parm_help = <<HELPHELP;
    -help               Print this message and exit.
HELPHELP

$CFG::logdir_parm_help = <<LDHELP;
    -logdir directory   Specify directory to write log file. The log file will
                        be given a unique name in this directory based
                        on the process ID and timestamp. Directory must be
                        writeable by the user.
                        Defaults:
                        UNIX: /var/adm/rational/clearcase/log/sync_logs
                        NT:   {CLEARCASEHOME}\\var\\log
LDHELP

$CFG::quiet_parm_help = <<QHELP;
    -quiet mode         Quiet mode = 1 will suppress all non-ERROR/WARNING
                        messages normally sent to STDOUT. If set to 2,
                        all STDOUT messages are suppressed.
                        (Default: 0 - prints various informational messages
                        and all warnings and errors).
QHELP

$CFG::view_parm_help = <<VHELP;
    -view viewtag       the view tag to use to help resolve pathnames
                        within a view context.
VHELP

if ($CFG::MScommon_version ne $CFG::MS_script_version) {
    die "Version mismatch between require file 'syncmgr_common.pl' " .
        "(version: ${CFG::MScommon_version}) and \n" .
        "the MultiSite parent script which includes it, $parent_script " .
        "(script version: ${CFG::MS_script_version}).\n" . 
		"Ensure old versions of the script/require file are not in use.\n";
}

sub RemoveLockwaitEV {
    # remove LOCKWAIT e.v. if user has set in the environment; 
    # specify "-lockwait" on the command line instead.
    if ($ENV{CLEARCASE_VOBLOCKWAIT}) {
        delete $ENV{CLEARCASE_VOBLOCKWAIT};
        qprint "WARNING: removed CLEARCASE_VOBLOCKWAIT env. variable.\n" .
            "Use '-lockwait <minutes>' parameter when invoking this script.\n";
    }
}

sub ConsTmpFile {
    # construct a tmp file name using dir + base + date/time/pid/sequence.
    # Check the file name, ensuring that it didn't exist before; if it does
    # bump the sequence and get a new timestamp.
    my $base = shift;
    if (!$base) {
        $base = 'tmp';
    }
    my $seq = 1;
    my $tmpname;

    while (-e ($tmpname = "${base}-" . MakeTimestamp() . "-$$" . "-$seq")) {
        ++$seq;
    }

    return $tmpname;
}

sub MakeBlockingExpr {
    # make appropriate 'blocking' param for multitool given the params
    # spec'd on the command line
    my ($nblock, $block_dur, $wait_forever) = @_;

    my $expr = "-wait_forever ";  # by default
    if ($nblock) {
        $expr = "-nblocking ";
	}

    if ($block_dur) {
        $expr = "-blocking_duration $block_dur ";
    }
    return $expr;
}
    
1;
